@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: gtkentryaction.c,v 1.4 2006/03/22 01:48:29 bmsmith Exp $
+ *  $Id: gtkentryaction.c 2537 2006-05-29 18:44:49Z dscorgie $
  */
 
 #include "config.h"
@@ -119,7 +119,7 @@ sync_label (GtkAction *gaction,
   GtkEntryAction *action = GTK_ENTRY_ACTION (gaction);
   GtkToolItem *item = GTK_TOOL_ITEM (proxy);
   GtkLabel *label = GTK_LABEL (g_object_get_data (G_OBJECT (item), "label"));
-  char *text;
+  char *text = NULL;
 
   g_object_get (action, "label", &text, NULL);
   gtk_label_set_text_with_mnemonic (label, text);
@@ -127,6 +127,7 @@ sync_label (GtkAction *gaction,
     gtk_widget_show (GTK_WIDGET (label));
   else
     gtk_widget_hide (GTK_WIDGET (label));
+  g_free (text);
 }
 
 static void
