@@ -29,9 +29,10 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-href.h>
 #include <string.h>
+
 #include "yelp-settings.h"
+#include "yelp-debug.h"
 
 #define KEY_GNOME_DIR           "/desktop/gnome/interface"
 #define KEY_GNOME_VARIABLE_FONT KEY_GNOME_DIR "/document_font_name"
@@ -44,12 +45,6 @@
 #define KEY_YELP_VARIABLE_FONT  KEY_YELP_DIR "/variable_font"
 #define KEY_YELP_FIXED_FONT     KEY_YELP_DIR "/fixed_font"
 
-#ifdef YELP_DEBUG
-#define d(x) x
-#else
-#define d(x)
-#endif
-
 static const gchar * const color_params[YELP_NUM_COLORS] = {
     "yelp.color.fg",
     "yelp.color.bg",
@@ -266,6 +261,9 @@ yelp_settings_open_preferences (void)
 	gtk_font_button_set_font_name (GTK_FONT_BUTTON (fixed_font_widget), font);
 	g_free (font);
 
+	use = gconf_client_get_bool (gconf_client, KEY_YELP_USE_CARET, NULL);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (use_caret_widget), use);
+
 	use_caret_handler =
 	    g_signal_connect (G_OBJECT (use_caret_widget), "toggled",
 			      G_CALLBACK (prefs_use_caret_cb), NULL);
@@ -325,6 +323,18 @@ yelp_settings_notify_remove (YelpSettingsType type, guint id)
 	    g_hook_destroy (hook_lists[i], id);
 }
 
+
+void
+yelp_settings_toggle_caret (void)
+{
+    gboolean caret;
+
+    caret = gconf_client_get_bool (gconf_client, KEY_YELP_USE_CARET, NULL);
+    gconf_client_set_bool (gconf_client,
+			   KEY_YELP_USE_CARET,
+			   !caret, NULL);
+}
+
 /** Getters *******************************************************************/
 
 const GtkIconTheme *
@@ -518,7 +528,7 @@ gconf_system_fonts_cb (GConfClient   *client,
 {
     gboolean use;
 
-    d (g_print ("gconf_system_fonts_cb\n"));
+    debug_print (DB_FUNCTION, "entering\n");
 
     use = gconf_value_get_bool (gconf_entry_get_value (entry));
 
@@ -541,7 +551,7 @@ gconf_font_cb (GConfClient   *client,
     gulong handler;
     const gchar *font;
 
-    d (g_print ("gconf_font_cb\n"));
+    debug_print (DB_FUNCTION, "entering\n");
 
     font = gconf_value_get_string (gconf_entry_get_value (entry));
 
@@ -590,7 +600,7 @@ gconf_use_caret_cb (GConfClient  *client,
 static void
 gtk_theme_changed (GtkSettings *settings, gpointer user_data)
 {
-    d (g_print ("gtk_theme_changed\n"));
+    debug_print (DB_FUNCTION, "entering\n");
 
     settings_update (YELP_SETTINGS_INFO_COLOR);
 }
@@ -612,7 +622,7 @@ settings_update (YelpSettingsType type)
     guint16    rval, gval, bval;
     gint i;
 
-    d (g_print ("settings_update\n"));
+    debug_print (DB_FUNCTION, "entering\n");
 
     if (type & YELP_SETTINGS_INFO_COLOR) {
 	style = gtk_rc_get_style_by_paths (gtk_settings,
@@ -644,8 +654,8 @@ settings_update (YelpSettingsType type)
 		    style->base[GTK_STATE_NORMAL].blue >> 8);
 
 	/* YELP_COLOR_ANCHOR */
-	widget = gnome_href_new ("http://www.gnome.org/", "GNOME");
-	gtk_widget_style_get (widget, "link_color", &color, NULL);
+	widget = gtk_link_button_new ("http://www.gnome.org");
+	gtk_widget_style_get (widget, "link-color", &color, NULL);
 	if (!color)
 	    color = &blue;
 	g_snprintf (colors[YELP_COLOR_ANCHOR], 8,
